/*
 * Copyright (C) 2005 Aurelien Mino <a.mino@free.fr>
 * Adapted from the GCFilms plugin written by Tian
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

using PluginLib;
using MovieDatabase;
using System;
using System.IO;
using System.Collections;
using Gtk;
using Gdk;
using Glade;

public class AMCImport_Plugin : ImportPlugin
{
    bool Result = false;
    string LastFile = string.Empty;
	Importer AMCImporter;

    [Widget] Gtk.ScrolledWindow AMCMoviesListContainer_GtkScrolledWindow;
    [Widget] Gtk.Window Window_Import_GtkWindow;
    [Widget] Gnome.FileEntry FileEntry_GnomeFileEntry;
    [Widget] Gtk.Button SelectAll_GtkButton;
    [Widget] Gtk.Button SelectNone_GtkButton;

    ToggleList FieldsList;
    
    public override int Initialize()
    {
        return 1;
    }

    public override string GetName()
    {
        return "Import from Ant Movie Catalog";
    }

    public override string GetAuthor()
    {
        return "Aurelien Mino <a.mino@free.fr>";
    }

    public override string GetDescription()
    {
        return "A plugin to import information from an Ant Movie Catalog binary file (.amc).";
    }

    public override bool Run()
    {
        Glade.XML gxml = new Glade.XML (null, "AMCImport.glade", "Window_Import_GtkWindow", null);
        gxml.Autoconnect (this);
        FieldsList = new ToggleList();

        AMCMoviesListContainer_GtkScrolledWindow.Add(FieldsList);
        
        FieldsList.ActivateSelectButtons(SelectAll_GtkButton, SelectNone_GtkButton);
        FieldsList.ShowAll();
        
		FileEntry_GnomeFileEntry.Changed +=new EventHandler(On_FileEntry_Changed);

        Application.Run();
        return Result;
    }

    public void OnWindowDeleteEvent (object o, DeleteEventArgs args) 
    {
        KillWindow(false);
    }

    public void KillWindow(bool _ret)
    {
        Window_Import_GtkWindow.Destroy();
        Result = _ret;
        Application.Quit ();
    }

    public void On_Cancel (object sender, EventArgs e)
    {
        KillWindow(false);
    }

	void On_FileEntry_Changed  (object _sender, EventArgs e) 
	{
	
		string __file = ((Gnome.FileEntry)_sender).GetFullPath(true);
		
		if ((__file != null) && File.Exists(__file) && !__file.Equals(LastFile) ) 
		{
	
			try {
	
				ArrayList __movies;
				LastFile = __file;
				if (AMCImporter != null) AMCImporter.CloseFile();
				AMCImporter = new Importer(__file);
				__movies = AMCImporter.Parse();

				FieldsList.Clear();
				int i=0;

				foreach (Movie __movie in __movies) 
				{
					string __title = __movie.Data[(int)MovieField.TRANSLATEDTITLE];
					if(__title == string.Empty) {
						__title = __movie.Data[(int)MovieField.TITLE];
					}
					
					FieldsList.AppendItem(i, true, __title);
				
					i++;
				}
				
				
		
			} catch (Exception excp) {
	            // Fallback
	            MessageDialog md = new MessageDialog(Window_Import_GtkWindow, DialogFlags.DestroyWithParent, 
	                                                 MessageType.Warning, ButtonsType.Close, excp.Message);
	            
	            md.Run();
	            md.Destroy();
	
				LastFile = string.Empty;
				FieldsList.Clear();
				
				if (AMCImporter != null) AMCImporter.CloseFile();
				AMCImporter = null;
	            
	            return;
	        }
	
		}
	}


    public void On_OK_Clicked (object sender, EventArgs e)
    {
        try 
            {
                                
                // Get the int reference
                int[] __Sel = FieldsList.CollectMapping();
                if (FileEntry_GnomeFileEntry.Filename == "") throw new Exception("You have to select a file!");
                //Importer __Importer = new Importer(FileEntry_GnomeFileEntry.Filename, __Sel);
                AMCImporter.SetSelection(__Sel);
				AMCImporter.Run();
                AMCImporter.CloseFile();
                int __count = AMCImporter.ImportedMovies;
                
                if (__count == 0) throw new Exception("Not a single movie could be imported from the specified file! Please check if ....");
                // Success
                MessageDialog md = new MessageDialog(Window_Import_GtkWindow, DialogFlags.DestroyWithParent, 
                                                     MessageType.Info, ButtonsType.Close, __count + 
                                                     " movies were imported into the database.");
                
                LastFile = string.Empty;
                
                md.Run();
                md.Destroy();
                KillWindow(true);
                
                }
        catch (Exception excp) {
            // Fallback
            MessageDialog md = new MessageDialog(Window_Import_GtkWindow, DialogFlags.DestroyWithParent, 
                                                 MessageType.Warning, ButtonsType.Close, excp.Message);
            
            md.Run();
            md.Destroy();
            
            return;
        }
        
        
    }


    
}
