/*
 * Copyright (C) 2004, 2005 Michael Dominic K. (http://www.mdk.org.pl)
 * Copyright (C) 2005 Aurelien Mino <a.mino@free.fr>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */


using System;
using Gtk;
using Gdk;

class ToggleList : Gtk.TreeView
{
    Gtk.TreeStore Store = new Gtk.TreeStore(typeof(int), typeof(bool), /*typeof(Pixbuf),*/ typeof(string));
    Gtk.Button SelectAll_GtkButton = null;
    Gtk.Button SelectNone_GtkButton = null;
    
    /* Toggle callback */
  	void OnFieldsToggled (object _o, ToggledArgs _args) 
    {
    
	    TreeIter __iter = new TreeIter();
	    Store.GetIter(out __iter, new TreePath(_args.Path));
	    // Get current toggle value
	    bool _currentstate = (bool) Store.GetValue(__iter, 1);
	    // Change toggle value
	    Store.SetValue(__iter, 1, !_currentstate);
    
    }
  

  
  public void AppendItem(int _Index, bool _State, /*Pixbuf _pixbuf,*/ string _Name) 
    {

    TreeIter lastrow = Store.AppendValues();
    // ID, first column
    Store.SetValue(lastrow, 0, _Index);
    Store.SetValue(lastrow, 1, _State);
	//Store.SetValue(lastrow, 2, _pixbuf);
    Store.SetValue(lastrow, 2, _Name);

    }

	public void Clear() 
	{
		Store.Clear();
	}
  

  public int[] GetToggledItems() 
    {
    
    TreeIter __iter = new TreeIter();
    
    // First find the number of toggled items
    Store.GetIterFirst(out __iter);
    
    int __count=0;
    bool __valid = true;
    
    while (__valid == true) 
      {
      if (((bool) Store.GetValue(__iter, 1)) == true) __count++;
      __valid = Store.IterNext(ref __iter);
      }
    
    if (__count == 0) return null;
    
    // Then create the mapping
    int [] __Mapping = new int[__count];
    
    Store.GetIterFirst(out __iter);
    __valid = true;
    int __i=0;
    while (__valid == true) 
      {
      if (((bool) Store.GetValue(__iter, 1)) == true) 
        { 
	__Mapping[__i] = (int) Store.GetValue(__iter, 0);
	__i++;
        }
      
      __valid = Store.IterNext(ref __iter);
      }
    
    return __Mapping;
    
    }
     
    

    // *** Constructor 
    public ToggleList() : base ()
    {
        
        this.Model = Store;
        this.HeadersVisible = false;
        this.RulesHint = true;
        
        // Toggle Renderer
        CellRendererToggle TGRenderer= new CellRendererToggle ();
        TGRenderer.Activatable = true;
        TGRenderer.Toggled += new ToggledHandler(OnFieldsToggled);
        
        this.AppendColumn ("Index", new CellRendererText (), "text", 0);
        this.AppendColumn ("Bool", TGRenderer, "active", 1);
        //this.AppendColumn ("Cover", new CellRendererPixbuf ());
        this.AppendColumn ("Name", new CellRendererText (), "text", 2);
        
        // Hide the Index Column
        TreeViewColumn __clmn = this.GetColumn(0);
        __clmn.Visible = false;
        
    }
    
    public void ActivateSelectButtons(Gtk.Button _SelectAll, Gtk.Button _SelectNone)
    {
        SelectAll_GtkButton = _SelectAll;
        SelectNone_GtkButton = _SelectNone;
        
        SelectAll_GtkButton.Clicked += new EventHandler(On_SelectButtons_Clicked);
        SelectNone_GtkButton.Clicked += new EventHandler(On_SelectButtons_Clicked);
    
    }

    void On_SelectButtons_Clicked  (object _sender, EventArgs _e) 
    {
      
        TreeIter __iter = new TreeIter();
    	bool __newState;
    
    	if (_sender == SelectAll_GtkButton) {
            __newState = true;
        }
        else {
            __newState = false;
        }
    
	    // First find the number of toggled items
	    Store.GetIterFirst(out __iter);
	    
	    bool __valid = true;
	    
	    while (__valid == true) 
	      {
	      Store.SetValue(__iter, 1, __newState);
	      __valid = Store.IterNext(ref __iter);
	      }
    }

    public int[] CollectMapping() 
    {
        TreeIter __iter = new TreeIter();
        
        // First find the number of toggled items
        Store.GetIterFirst(out __iter);
        
        int __count=0;
        bool __valid = true;
        
        while (__valid == true) {
            if (((bool) Store.GetValue(__iter, 1)) == true) __count++;
            __valid = Store.IterNext(ref __iter);
        }
    
    // EXCEPTION: Check if 0 toggled 
    if (__count == 0) {
      throw new Exception("You have to select at least one movie!");
    }
   
    // Then create the mapping
    int[] _Mapping = new int[__count];
    
    
    Store.GetIterFirst(out __iter);
    __valid = true;
    int __i=0;
    while (__valid == true) {
        if (((bool) Store.GetValue(__iter, 1)) == true) { 
            _Mapping[__i] = (int) Store.GetValue(__iter, 0);
            __i++;
        }
        
        __valid = Store.IterNext(ref __iter);
    }
    
    return _Mapping;
    }


  }
